@@ -152,7 +152,7 @@ class BaseProvider:
         """
         return DatasetD.dataset_info(dataset)
 
-    def datasets(self, instruments, fields, start_time=None, end_time=None, dataset=None):
+    def datasets(self, dataset=None, instruments="all", fields=None, start_time=None, end_time=None):
         """
         :param instruments: instruments list or market (ei. "zz500", "hs300", "zz800", "zz1000", "all"
         :param fields:  features str or list
@@ -169,7 +169,7 @@ class BaseProvider:
         fields = list(fields)
         return DatasetD.datasets(instruments, fields, start_time, end_time, dataset)
 
-    def datasets_fl(self, filt, fields, dataset=None, **kwargs):
+    def datasets_fl(self, dataset, fields=None, filt=None, **kwargs):
         """
         :param filt: conditions to filt the dataset
         :param fields:
@@ -225,13 +225,13 @@ class CalendarProvider:
             if start_time > _calendar[-1]:
                 return np.array([])
         else:
-            start_time = _calendar[0]
+            start_time = cal_config[freq]["si"]
         if end_time:
             end_time = to_intdate(end_time)
             if end_time < _calendar[0]:
                 return np.array([])
         else:
-            end_time = _calendar[-1]
+            end_time = cal_config[freq]["ei"]
         si, ei = self.locate_index(start_time, end_time, freq)
         return _calendar[si: ei + 1]
 
