@@ -161,12 +161,11 @@ def version_configuration():
     save_json(cal_config, str(fname))
 
 
-def update_data(data_path=None):
+def update_data(data_path=None, src_path="T:\\data\\new_api_data"):
     if data_path is None:
         data_path = Path(read_datapath())
     if data_path.exists():
         shutil.rmtree(str(data_path))
-    src_path = "T:\\data\\new_api_data"
     tgt_path = str(data_path)
     shutil.copytree(src_path, tgt_path)
 
